# Copyright (c) 2014 Outpost Embedded, LLC
# This file is part of the rebar software package.
#
# rebar is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License version 2 as published by the Free
# Software Foundation.
#
# A copy of the license has been included in the COPYING file.

import apt_pkg


def initialize(config = None):
    apt_pkg.InitConfig()
    if config:
        for name, value in config.items():
            apt_pkg.Config.Set(name, value)
    apt_pkg.InitSystem()


def is_initialized():
    return bool(apt_pkg.Config.keys())


def check_initialized():
    if not is_initialized():
        raise AssertionError('apt_pkg not initialized')


def parse_tag_file(f):
    check_initialized()
    return apt_pkg.ParseTagFile(f)


def parse_depends(s):
    check_initialized()
    return apt_pkg.ParseDepends(s)


def parse_source_depends(s):
    check_initialized()
    return apt_pkg.ParseSrcDepends(s)


def config_get(name):
    check_initialized()
    return apt_pkg.Config.Get(name)


def upstream_version(s):
    check_initialized()
    return apt_pkg.upstream_version(s)
