# Copyright (c) 2009-2010 Outpost Embedded, LLC
# This file is part of the rebar software package.
#
# rebar is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License version 2 as published by the Free
# Software Foundation.
#
# A copy of the license has been included in the COPYING file.

from __future__ import with_statement

from pshell import CommandFailed, CommandSignalled

from rebar.tasks_ import Task, ComplexTask


class BuildStep(object):
    env = None

    virtualizer = None
    user_shell = None
    output = None

    def __init__(self, env, *args, **kwargs):
        self.env = env
        super(BuildStep, self).__init__(*args, **kwargs)

    def bind(self, virtualizer, user_shell, output):
        self.virtualizer = virtualizer
        self.user_shell = user_shell
        self.output = output

    def unbind(self):
        del self.virtualizer
        del self.user_shell
        del self.output

    def get_required_packages(self):
        return set([])


class SimpleBuildStep(BuildStep, Task):
    pass


class ComplexBuildStep(BuildStep, ComplexTask):
    def get_required_packages(self):
        packages = set([])
        for subtask in self.subtasks:
            packages.update(subtask.get_required_packages())
        return packages

    def run_subtask(self, subtask):
        subtask.bind(self.virtualizer, self.user_shell, self.output)
        try:
            for task_changes in super(ComplexBuildStep, self).run_subtask(subtask):
                yield task_changes
        finally:
            subtask.unbind()
