# Copyright (c) 2009-2014 Outpost Embedded, LLC
# This file is part of the rebar software package.
#
# rebar is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License version 2 as published by the Free
# Software Foundation.
#
# A copy of the license has been included in the COPYING file.

import copy

from rebar.util import StrFromUnicodeMixin
from rebar.exceptions import DisallowedArgumentError


class SymbolicConstant(StrFromUnicodeMixin):
    value = None

    def __init__(self, value):
        self.value = value

    def __unicode__(self):
        return unicode(self.value)

    def __repr__(self):
        return str(self)


class BootLoader(SymbolicConstant):
    allowed_locations = None

    location = None

    def __init__(self, value, allowed_locations):
        if not allowed_locations:
            raise ValueError(allowed_locations)

        super(BootLoader, self).__init__(value)

        self.allowed_locations = allowed_locations
        self.location = allowed_locations[0]

    def __unicode__(self):
        s = super(BootLoader, self).__unicode__()
        if self.location is not None:
            s = '%s(%s)' % (s, unicode(self.location))
        return s

    def __eq__(self, other):
        return (isinstance(other, BootLoader) and other.value == self.value)

    def __ne__(self, other):
        return not self.__eq__(other)

    def __call__(self, location):
        if location not in self.allowed_locations:
            raise DisallowedArgumentError(location, self.allowed_locations)

        result = copy.copy(self)
        result.location = location
        return result
