#!/bin/sh

SYSTEM_DRIVE='%%SYSTEM_DRIVE%%'
SYSTEM_PARTITION='%%SYSTEM_PARTITION%%'
FS='%%FS%%'
PARTMAP='%%PARTMAP%%'
ABSTRACTION='%%ABSTRACTION%%'
GRUB_DRIVE='%%GRUB_DRIVE%%'
GRUB_PARTITION='%%GRUB_PARTITION%%'

while [ $# -gt 0 ]; do
  option="${1}"
  shift

  case "${option}" in
    --device-map) shift ;;
    --device-map=*) ;;
    --target) target="${1}"; shift ;;
    --target=*) target="${option#--target=}" ;;
    --device) ;;
    -*)
      echo "unrecognized option: ${option}" >&2
      exit 1
      ;;
    *)
      if [ -n "${arg}" ]; then
        echo 'too many arguments' >&2
        exit 1
      fi
      arg="${option}"
      ;;
  esac
done

if [ -z "${target}" ]; then
  echo 'must specify target' >&2
  exit 1
fi

if [ -z "${arg}" ]; then
  echo 'missing argument' >&2
  exit 1
fi

case "${target}" in
  'device') result="${SYSTEM_PARTITION}" ;;
  'fs') result="${FS}" ;;
  'partmap') result="${PARTMAP}" ;;
  'abstraction') result="${ABSTRACTION}" ;;
  'drive')
    d="(${GRUB_DRIVE})"
    p="(${GRUB_DRIVE},${GRUB_PARTITION})"
    case "${arg}" in
      "${SYSTEM_DRIVE}") result="${d}" ;;
      "${SYSTEM_PARTITION}") result="${p}" ;;
      /dev/disk/by-id/*-part[0-9]) result="${p}" ;;
      /dev/disk/by-id/*) result="${d}" ;;
      /dev/disk/by-label/*) result="${p}" ;;
      /dev/disk/by-path/*-part[0-9]) result="${p}" ;;
      /dev/disk/by-path/*) result="${d}" ;;
      /dev/disk/by-uuid/*) result="${p}" ;;
    esac
    ;;
esac

# Empty result is permitted for abstraction only.
if [ "${target}" != 'abstraction' -a -z "${result}" ]; then
  echo "result not known for ${target} ${arg}" >&2
  exit 1
fi

echo "${result}"
