# Copyright (c) 2007-2009 Outpost Embedded, LLC
# This file is part of the rebar software package.
#
# rebar is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License version 2 as published by the Free
# Software Foundation.
#
# A copy of the license has been included in the COPYING file.

from rebar.util import StrFromUnicodeMixin


class Error(Exception):
    pass


class ErrorWithMessage(StrFromUnicodeMixin, Error):
    msg = None

    def __init__(self, msg):
        self.msg = msg

    def __unicode__(self):
        return unicode(self.msg)


class VirtualizerInitializationError(ErrorWithMessage):
    pass


class NoSuchBuildPhase(StrFromUnicodeMixin, ValueError):
    build_phase = None

    def __init__(self, build_phase):
        self.build_phase = build_phase

    def __unicode__(self):
        return unicode(u'No such build phase: %s' % self.build_phase)


class RebarSyntaxError(ErrorWithMessage):
    pass


class DisallowedArgumentError(RebarSyntaxError):
    value = None
    allowed = None

    def __init__(self, value, allowed):
        self.value = value
        self.allowed = allowed

    def __unicode__(self):
        return u'Must be one of %s: %s' % (
          ', '.join([unicode(x) for x in self.allowed]),
          self.value,
        )


class MissingRequiredArgumentError(RebarSyntaxError):
    arg = None

    def __init__(self, arg):
        self.arg = arg

    def __unicode__(self):
        return u'Missing required argument %s.' % self.arg


class InvalidSourcePackageError(ErrorWithMessage):
    def __unicode__(self):
        return u'Invalid source package: %s' % self.msg


class DiskImageError(ErrorWithMessage):
    def __unicode__(self):
        return u'Disk image error: %s' % self.msg
