# Copyright (c) 2007-2010 Outpost Embedded, LLC
# This file is part of the rebar software package.
#
# rebar is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License version 2 as published by the Free
# Software Foundation.
#
# A copy of the license has been included in the COPYING file.

import getpass

from pshell import (
  Shell as _Shell,
  SudoShell as _SudoShell,
  CommandFailed,
  PasswordRequired,
)


class RebarShellMixin(object):
    def listdir(self, path = './'):
        # Ensure path ends with exactly one slash so that we can reliably
        # manipulate paths.
        path = '%s/' % path.rstrip('/')
        status, output = self.execute(
          'find ? -mindepth 1 -maxdepth 1 -print0',
          path,
        )
        entries = []
        # Split on null bytes and ignore the last item, which is an empty
        # string.
        items = output.split('\00')[:-1]
        for item in items:
            # Strip of leading path component.  We want entries, not full
            # paths.
            entry = item[len(path):]
            entries.append(entry)
        return entries

    def eval(self, *args, **kwargs):
        try:
            status, output = self.execute(*args, **kwargs)
        except CommandFailed, e:
            status, output = e.status, e.output

        return status


class Shell(RebarShellMixin, _Shell):
    pass


class SudoShell(RebarShellMixin, _SudoShell):
    @classmethod
    def InitializeInteractive(cls, password = None, **kwargs):
        while True:
            try:
                inst = cls(password = password, **kwargs)
            except PasswordRequired:
                password = getpass.getpass()
            else:
                break
        return inst, password
