# Copyright (c) 2007-2010 Outpost Embedded, LLC
# This file is part of the rebar software package.
#
# rebar is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License version 2 as published by the Free
# Software Foundation.
#
# A copy of the license has been included in the COPYING file.

from tasks import (
  Task as _Task,
  ComplexTask as _ComplexTask,
)


class NameMixin(object):
    def __init__(self, *args, **kwargs):
        # Allow name to be specified as a class attribute instead of an
        # initializer argument.
        if (not args) and ('name' not in kwargs):
            if self.name is None:
                raise AssertionError('name is None')
            kwargs['name'] = self.name
        super(NameMixin, self).__init__(*args, **kwargs)


# Our versions of Task and ComplexTask are aware of their depth within the task
# tree.  This makes output generation easier.


class Task(NameMixin, _Task):
    depth = None

    def __init__(self, *args, **kwargs):
        self.depth = 0
        super(Task, self).__init__(*args, **kwargs)

    def set_depth(self, depth):
        self.depth = depth


class ComplexTask(NameMixin, _ComplexTask):
    depth = None

    def __init__(self, *args, **kwargs):
        self.depth = 0
        super(ComplexTask, self).__init__(*args, **kwargs)

    def set_depth(self, depth):
        self.depth = depth
        for subtask in self.subtasks:
            subtask.set_depth(depth + 1)

    def add_subtask(self, subtask, *args, **kwargs):
        subtask.set_depth(self.depth + 1)
        super(ComplexTask, self).add_subtask(subtask, *args, **kwargs)
