# Copyright (c) 2007-2014 Outpost Embedded, LLC
# This file is part of the rebar software package.
#
# rebar is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License version 2 as published by the Free
# Software Foundation.
#
# A copy of the license has been included in the COPYING file.

from unittest import TestCase

from rebar.environment import (
  RebarEnvironment,
  MBR,
  VBR,
  GRUB,
  GRUB2,
  SYSLINUX,
)
from rebar.exceptions import RebarSyntaxError

from manager import manager


class TestRebarEnvironment(TestCase):
    def test_load_from_string(self):
        env = RebarEnvironment()
        s = "Repository('http://archive.ubuntu.com/ubuntu', 'hardy', ['main', 'universe'])"
        env.load_from_string(s)
        self.assertEqual(
          env['repositories'],
          [{
            'mirror': 'http://archive.ubuntu.com/ubuntu',
            'suite': 'hardy',
            'components': ['main', 'universe'],
            'architectures': None,
            'trusted': False,
          }],
        )

    def test_instance_independence(self):
        # This is largely a regression test.  RebarEnvironment.defaults was
        # being modified because list elements were not being copied.  This
        # tests that loading two environments gives the correct result for
        # both.
        env1 = RebarEnvironment()
        env2 = RebarEnvironment()
        s = "Repository('http://archive.ubuntu.com/ubuntu', 'hardy', ['main', 'universe'])"
        env1.load_from_string(s)
        env2.load_from_string(s)
        self.assertEqual(
          env1['repositories'],
          [{
            'mirror': 'http://archive.ubuntu.com/ubuntu',
            'suite': 'hardy',
            'components': ['main', 'universe'],
            'architectures': None,
            'trusted': False,
          }],
        )
        self.assertEqual(
          env1['repositories'],
          [{
            'mirror': 'http://archive.ubuntu.com/ubuntu',
            'suite': 'hardy',
            'components': ['main', 'universe'],
            'architectures': None,
            'trusted': False,
          }],
        )

manager.add_test_case_class(TestRebarEnvironment)


class TestBootLoaders(TestCase):
    def test_allowed_locations(self):
        GRUB(MBR)
        GRUB(VBR)
        GRUB2(MBR)
        GRUB2(VBR)
        self.assertRaises(RebarSyntaxError, SYSLINUX, MBR)
        SYSLINUX(VBR)

manager.add_test_case_class(TestBootLoaders)
