#!/usr/bin/env python

import os, timeit

from rebar.virtualizer.chroot import ChrootVirtualizer


sizes = ['1K', '1M', '10M', '100M']
filenames = ['%s.dat' % size for size in sizes]


print '*** creating data files'
for size, filename in zip(sizes, filenames):
    print filename
    if os.path.exists(filename):
        print 'using existing file'
    else:
        os.system('dd if=/dev/urandom bs=1 count=%s of=%s' % (size, filename))


with ChrootVirtualizer.Initialized('chroot', {}) as virtualizer:
    virtualizer.start()
    try:
        with virtualizer.open_base_platform() as platform:
            print '*** copy_to'
            for filename in filenames:
                print filename
                print timeit.repeat(
                  (lambda: platform.copy_to(filename, os.path.join('/tmp', filename))),
                  repeat = 3,
                  number = 1,
                )

            print '*** copy_from'
            for filename in filenames:
                print filename
                print timeit.repeat(
                  (lambda: platform.copy_from(os.path.join('/tmp', filename), 'tmp.dat')),
                  repeat = 3,
                  number = 1,
                )
                os.system('diff -q %s tmp.dat' % filename)

            with platform.open_shell() as sh:
                sh.execute('rm /tmp/*')

            os.unlink('tmp.dat')

    finally:
        virtualizer.stop()
